@@ -1,17 +1,18 @@
-# Copyright (C) 2018 Ioannis Kosmidis
+# Copyright (C) 2018- Ioannis Kosmidis
 
 #' Computes the dependence tree of a package
 #'
-#' @inheritParams package_by
+#' @inheritParams extractor-functions
 #' @param generation integer. The original generation for the package.
-#' @seealso build_dependence_tree
+#'
+#' @seealso [`build_dependence_tree.cranly_network`]
 #'
 #' @details
 #'
 #' Implements a recursion that computes the full dependence tree of a
-#' \code{package} from \code{x}. Specifically, the packages that are
-#' requirements for \code{package} (\code{Depends}, \code{Imports} or
-#' \code{LinkingTo}) are found, then the requirements for those
+#' `package` from `x`. Specifically, the packages that are
+#' requirements for `package` (`Depends`, `Imports` or
+#' `LinkingTo`) are found, then the requirements for those
 #' packages are found, and so on.
 #'
 #' @export
@@ -19,9 +20,10 @@ compute_dependence_tree <- function(x, package = NULL, generation = 0) {
     if (is.null(package)) {
         return(NULL) # return(unlist(x$nodes$Package))
     }
-    im <- imports(x, package = package, exact = TRUE)
-    de <- depends(x, package = package, exact = TRUE)
-    li <- linking_to(x, package = package, exact = TRUE)
+    im <- imported_by(x, package = package, exact = TRUE)
+    de <- dependency_of(x, package = package, exact = TRUE)
+    li <- linked_by(x, package = package, exact = TRUE)
+    
     pack <- na.omit(c(im, de, li))
     if (all(pack %in% package)) {
         data.frame(package = unique(package), generation = generation, stringsAsFactors = FALSE)
@@ -32,14 +34,16 @@ compute_dependence_tree <- function(x, package = NULL, generation = 0) {
     }
 }
 
-#' Construct a \code{\link{cranly_dependence_tree}} object
+#' Construct a [`cranly_dependence_tree`] object
 #'
 #' @aliases cranly_dependence_tree
 #' @inheritParams  plot.cranly_network
-#' @seealso compute_dependence_tree
 #'
+#' 
+#' @seealso [`compute_dependence_tree`] [`plot.cranly_dependence_tree`] [`summary.cranly_dependence_tree`]
+#' 
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' cran_db <- clean_CRAN_db()
 #' package_network <- build_network(object = cran_db)
 #' dep_tree <- build_dependence_tree(package_network, package = "PlackettLuce")
@@ -67,7 +71,7 @@ build_dependence_tree.cranly_network <- function(x,
     package <- unique(d_tree$package)
 
     x <- subset(x, package = package, author = Inf,
-                directive = c("imports", "depends", "linkingto"),
+                directive = c("imports", "depends", "linking_to"),
                 exact = TRUE, only = TRUE,
                 base = base, recommended = recommended)
 
@@ -90,50 +94,47 @@ build_dependence_tree.cranly_network <- function(x,
     x
 }
 
-#' summary method for \code{\link{cranly_dependence_tree}} objects
+#' summary method for [`cranly_dependence_tree`] objects
 #'
-#' Hard-dependence summaries for R packages from a \code{\link{cranly_dependence_tree}} object
+#' Hard dependence summaries for R packages from a [`cranly_dependence_tree`] object
 #'
-#' @param object a \code{\link{cranly_dependence_tree}} object
-#' @param ... currently not used
+#' @param object a [`cranly_dependence_tree`] object.
+#' @param ... currently not used.
 #'
 #' @return
 #'
-#' A list with components \code{n_generations}, \code{parents}, and
-#' \code{dependence_index}.
+#' A list with components `n_generations`, `parents`, and `dependence_index`.
 #'
 #' @details
 #'
-#' The summary method for a \code{\link{cranly_dependence_tree}}
-#' object returns the number of generations the R package(s) in the
-#' object inherit from (\code{n_generations}), the immediate
-#' parents of the R package(s) (\code{parents}), and a dependence
-#' index \code{dependence_index} defined as
-#' \deqn{
-#' -\frac{\sum_{i \in C_p; i \ne p} \frac{1}{N_i} g_i}{\sum_{i \in C_p; i \ne p} \frac{1}{N_i}}
-#' }
+#' The summary method for a [`cranly_dependence_tree`] object returns
+#' the number of generations the R package(s) in the object inherit
+#' from (`n_generations`), the immediate parents of the R package(s)
+#' (`parents`), and a dependence index `dependence_index` defined as
+#' \deqn{ -\frac{\sum_{i \in C_p; i \ne p} \frac{1}{N_i} g_i}{\sum_{i
+#' \in C_p; i \ne p} \frac{1}{N_i}} }
 #'
 #' where \eqn{C_p} is the dependence tree for the package(s) \eqn{p},
 #' \eqn{N_i} is the total number of packages that depend, link or
 #' import package \eqn{i}, and \eqn{g_i} is the generation that
 #' package \eqn{i} appears in the dependence tree of package(s)
 #' \eqn{p}. The generation takes values on the non-positive integers,
-#' with the package(s) \eqn{p} being placed at generation \code{0}, the
+#' with the package(s) \eqn{p} being placed at generation `0`, the
 #' packages that \eqn{p} links to, depends or imports at generation
-#' \code{-1} and so on.
+#' `-1` and so on.
 #'
 #' A dependence index of zero means that the \eqn{p} only has
 #' immediate parents. The dependence index weights the dependencies
 #' based on how popular these are, in the sense that the index is
-#' not penalised if the package depends on popular packages. The
+#' not penalized if the package depends on popular packages. The
 #' greatest the dependence index is the more baggage the package
 #' carries, and the maintainers may want to remove any dependencies
 #' that are not necessary.
 #'
-#' @seealso build_dependence_tree compute_dependence_tree
+#' @seealso [`build_dependence_tree.cranly_network`] [`compute_dependence_tree`]
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' cran_db <- clean_CRAN_db()
 #' package_network <- build_network(object = cran_db)
 #'
